@@ -24,9 +24,7 @@ describe 'gnocchi::storage::swift' do
 
   context 'on Debian platforms' do
     let :facts do
-      {
-        :osfamily       => 'Debian'
-      }
+      @default_facts.merge({ :osfamily => 'Debian' })
     end
 
     it_configures 'gnocchi storage swift'
@@ -34,9 +32,7 @@ describe 'gnocchi::storage::swift' do
 
   context 'on RedHat platforms' do
     let :facts do
-      {
-        :osfamily       => 'RedHat'
-      }
+      @default_facts.merge({ :osfamily => 'RedHat' })
     end
 
     it_configures 'gnocchi storage swift'
